@@ -1,4 +1,4 @@
-/* $Id: mountlist.c,v 1.11 2003/10/19 16:54:17 carlos Exp $ */
+/* $Id: mountlist.c,v 1.13 2003/10/20 15:19:36 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -26,7 +26,6 @@
 #include <glibtop.h>
 #include <glibtop/open.h>
 #include <glibtop/close.h>
-#include <glibtop/xmalloc.h>
 
 #include <glibtop/parameter.h>
 
@@ -73,7 +72,7 @@ main (int argc, char *argv [])
 	for (c = 0; c < PROFILE_COUNT; c++) {
 		mount_entries = glibtop_get_mountlist (&mount_list, 1);
 
-		glibtop_free (mount_entries);
+		g_free (mount_entries);
 	}
 
 	printf ("sbrk (0) = %p\n\n", sbrk (0));
@@ -103,7 +102,7 @@ main (int argc, char *argv [])
 			fsusage.ffree);
 	}
 
-	glibtop_free (mount_entries);
+	g_free (mount_entries);
 
 	printf ("\nsbrk (0) = %p\n\n", sbrk (0));
 
