@@ -1,4 +1,4 @@
-/* $Id: smp.c,v 1.3.2.1.2.1 2002/01/14 00:56:50 baddog Exp $ */
+/* $Id: smp.c,v 1.8 2003/10/20 15:19:36 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -22,10 +22,10 @@
 */
 
 #include <locale.h>
+#include <math.h>
 
 #include <glibtop.h>
 #include <glibtop/cpu.h>
-#include <glibtop/xmalloc.h>
 
 int
 main (int argc, char *argv [])
@@ -42,6 +42,8 @@ main (int argc, char *argv [])
 	bindtextdomain (GETTEXT_PACKAGE, GTOPLOCALEDIR);
 	textdomain (GETTEXT_PACKAGE);
 	
+	glibtop_init();
+
 	glibtop_get_cpu (&cpu);
 
 	ncpu = glibtop_global_server->ncpu ? glibtop_global_server->ncpu : 1;
