@@ -1,4 +1,4 @@
-/* $Id: close.h,v 1.11 2003/10/19 16:10:17 carlos Exp $ */
+/* $Id: close.h,v 1.12 2003/10/20 15:19:39 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -26,13 +26,13 @@
 
 #include <glibtop.h>
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
 
 void glibtop_close_r (glibtop *server);
 
 void glibtop_close_s (glibtop *server);
 void glibtop_close_p (glibtop *server);
 
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif
