@@ -1,3 +1,5 @@
+/* $Id: command.h,v 1.28 2003/10/20 15:19:39 hadess Exp $ */
+
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -55,12 +57,8 @@ G_BEGIN_DECLS
 #define GLIBTOP_CMND_FSUSAGE		21
 #define GLIBTOP_CMND_NETLOAD		22
 #define GLIBTOP_CMND_PPP		23
-#define GLIBTOP_CMND_NETLIST		24
-#define GLIBTOP_CMND_PROC_OPEN_FILES	25
-#define GLIBTOP_CMND_PROC_WD		26
-#define GLIBTOP_CMND_PROC_AFFINITY	27
 
-#define GLIBTOP_MAX_CMND		28
+#define GLIBTOP_MAX_CMND		24
 
 #define _GLIBTOP_PARAM_SIZE		16
 
@@ -71,8 +69,8 @@ typedef union  _glibtop_response_union	glibtop_response_union;
 
 struct _glibtop_command
 {
-	guint64	command;
-	guint64	size, data_size;
+	u_int64_t	command;
+	u_int64_t	size, data_size;
 	char		parameter [_GLIBTOP_PARAM_SIZE];
 };
 
@@ -84,8 +82,8 @@ union _glibtop_response_union
 
 struct _glibtop_response
 {
-	gint64 offset;
-	guint64 size, data_size;
+	int64_t offset;
+	u_int64_t size, data_size;
 	glibtop_response_union u;
 };
 
