@@ -1,4 +1,4 @@
-/* $Id: msg_limits.h,v 1.21 2003/10/19 16:10:17 carlos Exp $ */
+/* $Id: msg_limits.h,v 1.22 2003/10/20 15:19:39 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -27,7 +27,7 @@
 #include <glibtop.h>
 #include <glibtop/global.h>
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
 
 #define GLIBTOP_IPC_MSGPOOL	0
 #define GLIBTOP_IPC_MSGMAP	1
@@ -82,7 +82,7 @@ extern const char *glibtop_descriptions_msg_limits [];
 
 #endif
 
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif
 
