@@ -1,4 +1,4 @@
-/* $Id: procsignal.h,v 1.23 2003/10/19 16:10:17 carlos Exp $ */
+/* $Id: procsignal.h,v 1.24 2003/10/20 15:19:39 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -27,7 +27,7 @@
 #include <glibtop.h>
 #include <glibtop/global.h>
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
 
 #define GLIBTOP_PROC_SIGNAL_SIGNAL	0
 #define GLIBTOP_PROC_SIGNAL_BLOCKED	1
@@ -78,6 +78,6 @@ extern const char *glibtop_descriptions_proc_signal [];
 
 #endif
 
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif
