@@ -1,4 +1,4 @@
-/* $Id: proctime.h,v 1.23 2003/10/19 16:10:17 carlos Exp $ */
+/* $Id: proctime.h,v 1.24 2003/10/20 15:19:39 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -28,7 +28,7 @@
 #include <glibtop/cpu.h>
 #include <glibtop/global.h>
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
 
 #define GLIBTOP_PROC_TIME_START_TIME	0
 #define GLIBTOP_PROC_TIME_RTIME		1
@@ -99,6 +99,6 @@ extern const char *glibtop_descriptions_proc_time [];
 
 #endif
 
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif
