@@ -1,4 +1,4 @@
-/* $Id: write.c,v 1.12.2.2 2003/10/21 21:28:13 hadess Exp $ */
+/* $Id: write.c,v 1.13 2003/10/20 15:19:41 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -21,7 +21,10 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
+
 #include <glibtop/write.h>
+#include <libgnome/gnome-i18n.h>
 
 /* Writes some data to server. */
 
