@@ -1,4 +1,4 @@
-/* $Id: glibtop_server.h,v 1.15.2.1 2003/10/20 20:41:06 hadess Exp $ */
+/* $Id: glibtop_server.h,v 1.16 2003/10/20 15:19:56 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -27,7 +27,7 @@
 #include <fcntl.h>
 #include <ctype.h>
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
 
 #ifdef _IN_LIBGTOP
 
@@ -57,25 +57,6 @@ skip_line (const char *p)
 	return (char *) ++p;
 }
 
-static inline unsigned long
-get_scaled(const char *buffer, const char *key)
-{
-  const char    *ptr;
-  char          *next;
-  unsigned long value = 0;
-  
-  if ((ptr = strstr(buffer, key)))
-    {
-      ptr += strlen(key);
-      value = strtoul(ptr, &next, 0);
-      if (strchr(next, 'k'))
-	value *= 1024;
-      else if (strchr(next, 'M'))
-	value *= 1024 * 1024;
-    }
-  return value;
-}
-
 static inline int
 proc_file_to_buffer (char *buffer, const char *fmt, pid_t pid)
 {
@@ -149,6 +130,6 @@ proc_stat_after_cmd (char *p)
 #define GLIBTOP_SUID_NETLOAD		0
 #define GLIBTOP_SUID_PPP		0
 
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif
