@@ -1,4 +1,4 @@
-/* $Id: procmap.c,v 1.11 2003/10/19 16:55:39 carlos Exp $ */
+/* $Id: procmap.c,v 1.13 2003/10/20 15:19:56 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -23,7 +23,6 @@
 
 #include <glibtop.h>
 #include <glibtop/error.h>
-#include <glibtop/xmalloc.h>
 #include <glibtop/procmap.h>
 
 static const unsigned long _glibtop_sysdeps_proc_map =
@@ -107,7 +106,7 @@ glibtop_get_proc_map_s (glibtop *server, glibtop_proc_map *buf,	pid_t pid)
 
 		size = (n+1) * sizeof (glibtop_map_entry);
 
-		entry_list = glibtop_realloc_r (server, entry_list, size);
+		entry_list = g_realloc (entry_list, size);
 
 		memset (&(entry_list [n]), 0, sizeof (glibtop_map_entry));
 
