@@ -1,4 +1,4 @@
-/* $Id: proclist.c,v 1.12 2003/10/19 16:55:56 carlos Exp $ */
+/* $Id: proclist.c,v 1.14 2003/10/20 15:20:16 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -22,7 +22,6 @@
 */
 
 #include <glibtop.h>
-#include <glibtop/xmalloc.h>
 #include <glibtop/proclist.h>
 
 #include <glibtop_suid.h>
@@ -72,7 +71,7 @@ glibtop_get_proclist_p (glibtop *server, glibtop_proclist *buf,
 
 	proc_size = nproc * sizeof (unsigned);
 
-	proc_list = glibtop_malloc_r (server, proc_size);
+	proc_list = g_malloc (server, proc_size);
 
 	/* Write process list. */
 
